:mod:`~kanon.tables` --- Defining ancient astronomical tables
=============================================================

.. toctree::
  :maxdepth: 2

  htable.rst
  symmetries.rst
  interpolations.rst


.. automodapi:: kanon.tables
  :inherited-members:
